import Vue from "vue"
let prototype = Vue.prototype;

export default {
    listType: {
        // 普通订单
        T1: 't1',
        // 一口价/报价订单
        T2: 't2',
        // 货运订单
        T3: 't3',
        // 退款订单
        T4: 't4',
    },
    state: {
        t1: {
            S1: 0,
            S2: 1,
            S3: 2,
            S4: 4,
            S5: 5,
            S6: 6,
        },
        t2: {
            S1: 0,
            S2: 1,
            S3: 2,
            S4: 4,
            S5: 5,
            S6: 6,
        },
        t3: {},
        t4: {
            S1: 7,
            S2: 8,
            S3: 9,
        },
    },
    stateTextColor(listType, orderType, state) {
        switch (state) {
            default:
                return '#000000';
        }
    },
    stateText(listType, orderType, state) {
        let current = this.state[listType];
        if (listType == this.listType.T1) {
            switch (state) {
                case current.S1: return ['待支付', '为保证师傅按时上门，建议尽快选择师傅并完成支付'];
                case current.S2: return ['待师傅接单'];
                case current.S3: return ['服务中'];
                case current.S4: return ['待支付尾款'];
                case current.S5: return ['服务已完成，待确认'];
                case current.S6: return ['订单已完成'];
            }
        } else if (listType == this.listType.T2) {
            switch (state) {
                case current.S1:
                    if (orderType == 1) {
                        return ['待师傅接单'];
                    }
                    return ['待选择师傅'];
                case current.S2:
                    if (orderType == 1) {
                        return ['师傅已接单，待支付'];
                    }
                    return ['已选择师傅，待支付'];
                case current.S3: return ['服务中'];
                case current.S4: return ['待支付尾款'];
                case current.S5: return ['服务已完成，待确认'];
                case current.S6: return ['订单已完成'];
            }
        } else if (listType == this.listType.T3) {
            return ['未知状态'];
        } else if (listType == this.listType.T4) {
            switch (state) {
                case current.S1: return ['退款申请审核中'];
                case current.S2: return ['已退款'];
                case current.S3: return ['退款未通过'];
            }
        }

        return ['未知', '#000000'];
    },
    /**
     * 下单
     */
    createOrder(order) {
        return new Promise((resolve, reject) => {
            prototype.$request({
                api: "order.createOrder",
                data: order,
            }).then((response) => {
                if (response.code == 1) {
                    return resolve(response.data);
                }
                return reject(response.msg);
            }).catch(e => { });
        });
    },
    /**
     * 支付订单
     */
    payOrder(id) {
        return new Promise((resolve, reject) => {
            prototype.$request({
                api: "order.pay",
                data: {
                    id: id
                }
            }).then(response => {
                console.log(response);
            }).catch(e => {
                throw e
            });
        });
    },
    /**
     * 订单列表
     */
    orderList(options) {
        return new Promise((resolve, reject) => {
            prototype.$request(options.request).then(response => {
                if (response.code == 1) {
                    let list = [];
                    response.data.forEach((item) => {
                        list.push({
                            listType: options.listType,
                            id: item.id,
                            orderId: item.order,
                            cate: "待返数据",
                            content: item.desc,
                            createTime: item.time,
                            serviceTime: item.times,
                            orderType: item.types,
                            state: item.status,
                            worker: item.shifu,
                            workerList: [],
                        });
                    });
                    return resolve(list);
                }
                return reject(response.msg);
            }).catch(e => { });
        });
    },
    /**
     * 订单详情
     */
    orderDetail(options) {
        return new Promise((resolve, reject) => {
            prototype.$request(options.request).then(response => {
                if (response.code == 1) {
                    return resolve({
                        id: response.data.id,
                        address: response.data.address,
                        orderId: response.data.order,
                        cate: "待返数据",
                        content: response.data.desc,
                        createTime: response.data.time,
                        serviceTime: response.data.times,
                        orderType: response.data.types,
                        state: response.data.status,
                        images: [],
                        worker: [],
                        workerList: [],
                    });
                }
                return reject(response.msg);
            }).catch(e => { });
        });
    }
}
